==> ejc-panhuo-impl-3.0.0-20231226.024129-198-sources.jar: com/ejianc/business/panhuo/bean/PutawayEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.panhuo.bean.PutawayDetailEntity;
/**
 * 批量上架
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_putaway")
public class PutawayEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 资产编号
    @TableField(value="seller")
    private Long seller; // 发布人
    @TableField(value="seller_name")
    private String sellerName; // 发布人名称
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="address_id")
    private Long addressId; // 地址主键
    @TableField(value="address_name")
    private String addressName; // 出售项目
    @TableField(value="project_address")
    private String projectAddress; // 
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="first_location")
    private String firstLocation; // 所在地一级区域
    @TableField(value="second_location")
    private String secondLocation; // 所在地二级区域
    @TableField(value="third_location")
    private String thirdLocation; // 所在地三级区域
    @TableField(value="fourth_location")
    private String fourthLocation; // 所在地四级区域
    @TableField(value="location")
    private String location; // 所在地末级区域
    @TableField(value="lon")
    private Double lon; // 经度
    @TableField(value="lat")
    private Double lat; // 纬度
    @TableField(value="phone")
    private String phone; // 联系方式
    @TableField(value="name")
    private String name; // 联系人
    @TableField(value="material_names")
    private String materialNames; // 物料名称合计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="sum_shelf_mny")
    private BigDecimal sumShelfMny; // 上架金额汇总
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(exist = false)
    private String billStateName;


    @TableField(exist=false)
    @SubEntity(serviceName="putawayDetailService",pidName = "putawayId")
    private List<PutawayDetailEntity> putawayDetailList = new ArrayList<>(); // 批量上架子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public BigDecimal getSumShelfMny() {
        return sumShelfMny;
    }

    public void setSumShelfMny(BigDecimal sumShelfMny) {
        this.sumShelfMny = sumShelfMny;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getAddressId() {
        return addressId;
    }

    public void setAddressId(Long addressId) {
        this.addressId = addressId;
    }
    public String getAddressName() {
        return addressName;
    }

    public void setAddressName(String addressName) {
        this.addressName = addressName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getFirstLocation() {
        return firstLocation;
    }

    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    public String getSecondLocation() {
        return secondLocation;
    }

    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    public String getThirdLocation() {
        return thirdLocation;
    }

    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    public String getFourthLocation() {
        return fourthLocation;
    }

    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }
    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public List<PutawayDetailEntity> getPutawayDetailList() {
        return putawayDetailList;
    }

    public void setPutawayDetailList(List<PutawayDetailEntity> putawayDetailList) {
        this.putawayDetailList = putawayDetailList;
    }
}

==> ejc-panhuo-impl-3.0.0-20251013.062808-226-sources.jar: com/ejianc/business/panhuo/bean/PutawayEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.panhuo.bean.PutawayDetailEntity;
/**
 * 批量上架
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_putaway")
public class PutawayEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 资产编号
    @TableField(value="seller")
    private Long seller; // 发布人
    @TableField(value="seller_name")
    private String sellerName; // 发布人名称
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="address_id")
    private Long addressId; // 地址主键
    @TableField(value="address_name")
    private String addressName; // 出售项目
    @TableField(value="project_address")
    private String projectAddress; // 
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="first_location")
    private String firstLocation; // 所在地一级区域
    @TableField(value="second_location")
    private String secondLocation; // 所在地二级区域
    @TableField(value="third_location")
    private String thirdLocation; // 所在地三级区域
    @TableField(value="fourth_location")
    private String fourthLocation; // 所在地四级区域
    @TableField(value="location")
    private String location; // 所在地末级区域
    @TableField(value="lon")
    private Double lon; // 经度
    @TableField(value="lat")
    private Double lat; // 纬度
    @TableField(value="phone")
    private String phone; // 联系方式
    @TableField(value="name")
    private String name; // 联系人
    @TableField(value="material_names")
    private String materialNames; // 物料名称合计
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="sum_shelf_mny")
    private BigDecimal sumShelfMny; // 上架金额汇总
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(exist = false)
    private String billStateName;
    @TableField(value="pro_store_id")
    private Long proStoreId; //仓库id
    @TableField(value="pro_store_name")
    private String proStoreName; //仓库名称


    @TableField(exist=false)
    @SubEntity(serviceName="putawayDetailService",pidName = "putawayId")
    private List<PutawayDetailEntity> putawayDetailList = new ArrayList<>(); // 批量上架子表


    public Long getProStoreId() {
        return proStoreId;
    }

    public void setProStoreId(Long proStoreId) {
        this.proStoreId = proStoreId;
    }

    public String getProStoreName() {
        return proStoreName;
    }

    public void setProStoreName(String proStoreName) {
        this.proStoreName = proStoreName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public BigDecimal getSumShelfMny() {
        return sumShelfMny;
    }

    public void setSumShelfMny(BigDecimal sumShelfMny) {
        this.sumShelfMny = sumShelfMny;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getAddressId() {
        return addressId;
    }

    public void setAddressId(Long addressId) {
        this.addressId = addressId;
    }
    public String getAddressName() {
        return addressName;
    }

    public void setAddressName(String addressName) {
        this.addressName = addressName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getFirstLocation() {
        return firstLocation;
    }

    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    public String getSecondLocation() {
        return secondLocation;
    }

    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    public String getThirdLocation() {
        return thirdLocation;
    }

    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    public String getFourthLocation() {
        return fourthLocation;
    }

    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }
    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public List<PutawayDetailEntity> getPutawayDetailList() {
        return putawayDetailList;
    }

    public void setPutawayDetailList(List<PutawayDetailEntity> putawayDetailList) {
        this.putawayDetailList = putawayDetailList;
    }
}
